faradayio - Faraday Proxy Input/Output Toolset
======================================

Faraday IO is a basic Python toolset that can be used to interact with the RESTful API connecting the Faraday Digital Radio to a localhost server. This toolset includes basic input and output functionality along with command and parsing definitions to jumpstart application development.

.. automodule:: faradaybasicproxyio
    :members:
